@@ -1,11 +1,11 @@
 package Path::Class::File;
 
-$VERSION = '0.18';
+$VERSION = '0.19';
 
 use strict;
 use Path::Class::Dir;
-use Path::Class::Entity;
 use base qw(Path::Class::Entity);
+use Carp;
 
 use IO::File ();
 
@@ -20,12 +20,14 @@ sub new {
     push @dirs, $self->_spec->catpath($volume, $dirs, '');
   }
   
-  $self->{dir}  = @dirs ? Path::Class::Dir->new(@dirs) : undef;
+  $self->{dir}  = @dirs ? $self->dir_class->new(@dirs) : undef;
   $self->{file} = $base;
   
   return $self;
 }
 
+sub dir_class { "Path::Class::Dir" }
+
 sub as_foreign {
   my ($self, $type) = @_;
   local $Path::Class::Foreign = $self->_spec_class($type);
@@ -44,7 +46,7 @@ sub stringify {
 sub dir {
   my $self = shift;
   return $self->{dir} if defined $self->{dir};
-  return Path::Class::Dir->new($self->_spec->curdir);
+  return $self->dir_class->new($self->_spec->curdir);
 }
 BEGIN { *parent = \&dir; }
 
@@ -57,8 +59,8 @@ sub volume {
 sub basename { shift->{file} }
 sub open  { IO::File->new(@_) }
 
-sub openr { $_[0]->open('r') or die "Can't read $_[0]: $!"  }
-sub openw { $_[0]->open('w') or die "Can't write $_[0]: $!" }
+sub openr { $_[0]->open('r') or croak "Can't read $_[0]: $!"  }
+sub openw { $_[0]->open('w') or croak "Can't write $_[0]: $!" }
 
 sub touch {
   my $self = shift;
@@ -72,7 +74,8 @@ sub touch {
 
 sub slurp {
   my ($self, %args) = @_;
-  my $fh = $self->openr;
+  my $iomode = $args{iomode} || 'r';
+  my $fh = $self->open($iomode) or croak "Can't read $self: $!";
 
   if ($args{chomped} or $args{chomp}) {
     chomp( my @data = <$fh> );
@@ -194,7 +197,7 @@ return false, and C<Path::Class::Dir> objects always return true.
 Returns true or false depending on whether the file refers to an
 absolute path specifier (like C</usr/local/foo.txt> or C<\Windows\Foo.txt>).
 
-=item $file->is_absolute
+=item $file->is_relative
 
 Returns true or false depending on whether the file refers to a
 relative path specifier (like C<lib/foo.txt> or C<.\Foo.txt>).
@@ -270,13 +273,13 @@ fails, C<undef> is returned and C<$!> is set.
 
 A shortcut for
 
- $fh = $file->open('r') or die "Can't read $file: $!";
+ $fh = $file->open('r') or croak "Can't read $file: $!";
 
 =item $fh = $file->openw()
 
 A shortcut for
 
- $fh = $file->open('w') or die "Can't write $file: $!";
+ $fh = $file->open('w') or croak "Can't write $file: $!";
 
 =item $file->touch
 
@@ -296,6 +299,16 @@ for the C<chomp> or C<chomped> parameters:
 
   my @lines = $file->slurp(chomp => 1);
 
+You may also use the C<iomode> paramter to pass in an IO mode to use
+when opening the file, usually IO layers (though anything accepted by
+the MODE argument of C<open()> is accepted here).  Just make sure it's
+a I<reading> mode.
+
+  my @lines = $file->slurp(iomode => ':crlf');
+  my $lines = $file->slurp(iomode => '<:encoding(UTF−8)');
+
+The default C<iomode> is C<r>.
+
 =item $file->remove()
 
 This method will remove the file in a way that works well on all
@@ -317,6 +330,12 @@ C<File::stat> object representing the result.
 Same as C<stat()>, but if C<$file> is a symbolic link, C<lstat()>
 stats the link instead of the file the link points to.
 
+=item $class = $file->dir_class()
+
+Returns the class which should be used to create directory objects.
+
+Generally overriden whenever this class is subclassed.
+
 =back
 
 =head1 AUTHOR
